import { JSX, Component, Owner, Accessor, Setter } from 'solid-js';
import { Queries, queries, BoundFunctions, prettyFormat } from '@testing-library/dom';
export * from '@testing-library/dom';

type Ui = () => JSX.Element;
interface Options {
    container?: HTMLElement;
    baseElement?: HTMLElement;
    queries?: Queries & typeof queries;
    hydrate?: boolean;
    wrapper?: Component<{
        children: JSX.Element;
    }>;
}
type DebugFn = (baseElement?: HTMLElement | HTMLElement[], maxLength?: number, options?: prettyFormat.OptionsReceived) => void;
type Result = BoundFunctions<typeof queries> & {
    asFragment: () => string;
    container: HTMLElement;
    baseElement: HTMLElement;
    debug: DebugFn;
    unmount: () => void;
};
type RenderHookOptions<A extends any[]> = {
    initialProps?: A;
    wrapper?: Component<{
        children: JSX.Element;
    }>;
} | A;
type RenderHookResult<R> = {
    result: R;
    owner: Owner | null;
    cleanup: () => void;
};
type RenderDirectiveOptions<A extends any, E extends HTMLElement = HTMLDivElement> = Options & {
    initialValue?: A;
    targetElement?: Lowercase<E['nodeName']> | E | (() => E);
};
type RenderDirectiveResult<A extends any> = Result & {
    arg: Accessor<A>;
    setArg: Setter<A>;
};

declare function render(ui: Ui, options?: Options): Result;
declare function renderHook<A extends any[], R>(hook: (...args: A) => R, options?: RenderHookOptions<A>): RenderHookResult<R>;
declare function renderDirective<A extends any, U extends A, E extends HTMLElement>(directive: (ref: E, arg: Accessor<U>) => void, options?: RenderDirectiveOptions<U, E>): RenderDirectiveResult<U>;
declare function cleanup(): void;

export { cleanup, render, renderDirective, renderHook };
